@@ -67,6 +67,9 @@ private Q_SLOTS:
     void testVariablesStartSecondSession();
     void testVariablesSwitchFrame();
     void testVariablesQuicklySwitchFrame();
+    void testSegfaultDebugee();
+    void testSwitchFrameGdbConsole();
+    void testInsertAndRemoveBreakpointWhileRunning();
 private:
     KDevelop::TestCore* m_core;
     void waitForState(GDBDebugger::DebugSession *session, KDevelop::IDebugSession::DebuggerState state, const char *file, int line);
