@@ -41,7 +41,10 @@ namespace Cpp {
 class KDEVCPPDUCHAIN_EXPORT NameASTVisitor: protected DefaultVisitor
 {
 public:
-  NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const KDevelop::SimpleCursor& position, KDevelop::DUContext::SearchFlags localSearchFlags = KDevelop::DUContext::NoSearchFlags, bool debug = false);
+  ///@param context Context in which to look up the name
+  ///@param source The source top-context from where the parsing was triggerd
+  ///@param localVisibilityContext Local context from where to look up template parameters
+  NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const KDevelop::DUContext* localVisibilityContext, const KDevelop::SimpleCursor& position, KDevelop::DUContext::SearchFlags localSearchFlags = KDevelop::DUContext::NoSearchFlags, bool debug = false);
 
   void run(NameAST *node, bool skipLastNamePart = false);
   ///@param skipThisName if this is true, only the template-parameters of the given node are processed
@@ -65,6 +68,9 @@ public:
     return m_stopSearch;
   }
   
+  ///Whether at least one part of the scope could be resolved
+  DeclarationPointer foundSomething() const;
+  
   ///This can be used from outside to only process the type of a template-argument.
   ///This NameASTVisitor will be in an invalid state after this is called, so don't continue using it!
   Cpp::ExpressionEvaluationResult processTemplateArgument(TemplateArgumentAST *node);
@@ -77,6 +83,7 @@ private:
   Cpp::ExpressionVisitor* m_visitor;
   const KDevelop::DUContext* m_context;
   const KDevelop::TopDUContext* m_source;
+  const KDevelop::DUContext* m_localContext;
   TypeSpecifierAST* m_typeSpecifier;
   KDevelop::Identifier m_currentIdentifier;
   KDevelop::QualifiedIdentifier _M_name;
@@ -85,6 +92,7 @@ private:
   UnqualifiedNameAST* m_finalName;
   KDevelop::DUContext::SearchFlags m_flags;
   bool m_stopSearch;
+  DeclarationPointer m_foundSomething;
 };
 
 QString decode(ParseSession* session, AST* ast, bool without_spaces = false);
